@@ -2,11 +2,13 @@
 from .Hydraulic_Models_Data import *
 from .Calibration import *
 from .Misc import *
+from .cli import *
 
 from .__about__ import __version__
 from .__common__ import *
 
 __all__ = [
+    "cli",
     "Hydraulic_Models_Data_Base",
     "Backwater_1D",
     "SRH_2D",
@@ -19,7 +21,6 @@ __all__ = [
     "__version__"
 ]
 
-__version_info__ = (1, 0, 0)
-__version__ = '.'.join(map(str, __version_info__))
+
 
 
